==> spip_3.0.21.orig.tar.xz: spip/plugins-dist/petitions/lang/petitions_he.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/petitions?lang_cible=he
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) return;

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// F
	'form_pet_adresse_site' => 'הכתובת הכללית של האתר שלך', # MODIF
	'form_pet_aucune_signature' => 'שום חתימה לא מתאימה לקוד...', # MODIF
	'form_pet_confirmation' => 'נא אשר את חתימתך.',
	'form_pet_deja_signe' => 'כבר חתמת על הטקסט הזה.',
	'form_pet_envoi_mail_confirmation' => 'דוא"ל אישור נשלח לכתובת @email@. נא להקליק בקישור שצוין בהודעה כדי לתת תוקף לחתימתך.', # MODIF
	'form_pet_mail_confirmation' => 'שלום,

ביקשת לתחתום את הפטיציה הבאה:
@titre@.

הכנסת את הפרטים הבאים:
    שם: @nom_email@
    אתר: @nom_site@ - @url_site@

לתשומת לבך...
כדי לאשר את חתימתך, צריך שתתחבר/י 
לכתובת הבאה (אם לא, אז בקשתך
תימאס):
    @url@

תודה על השתתפותך
',
	'form_pet_nom_site2' => 'שם האתר שלך', # MODIF
	'form_pet_probleme_liens' => 'נא לתקן את הודעתך בהסרת הקישורים.',
	'form_pet_probleme_technique' => 'בעיה טכנית, חתימות לא עובדות כרגע.',
	'form_pet_signature_validee' => 'החתימה שלך מקובלת. תודה לך !',
	'form_pet_site_deja_enregistre' => 'האתר הזה כבר רשום במערכת',
	'form_pet_url_invalide' => 'הכתובת הכללית שכתבת לא ברת תוקף.',
	'form_pet_votre_email' => 'כתובת הדוא"ל שלך',
	'form_pet_votre_nom' => 'השם או הכינוי שלך', # MODIF
	'form_pet_votre_site' => 'אם ברשותך אתר, כתוב את כתובתו להלן',

	// I
	'info_adresse_email' => ':כתובת דוא"ל',
	'info_signature_supprimee' => 'חתימה נמחקה',
	'info_signature_supprimee_erreur' => 'טעות : קוד המחיקה לא מתאים לאף חתימה', # MODIF
	'info_site_web' => 'אתר אינטרנט :'
);

?>

==> spip_3.1.4.orig.tar.xz: spip/plugins-dist/petitions/lang/petitions_he.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/petitions?lang_cible=he
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// B
	'bouton_radio_activer_petition' => 'להפעיל את העצומה',
	'bouton_radio_pas_petition' => 'אין עצומה',
	'bouton_radio_petition_activee' => 'עצומה מופעלת',
	'bouton_radio_supprimer_petition' => 'מחק את העצומה',

	// F
	'form_pet_adresse_site' => 'הכתובת הכללית של האתר שלך', # MODIF
	'form_pet_aucune_signature' => 'שום חתימה לא מתאימה לקוד...', # MODIF
	'form_pet_confirmation' => 'נא אשר את חתימתך.',
	'form_pet_deja_signe' => 'כבר חתמת על הטקסט הזה.',
	'form_pet_envoi_mail_confirmation' => 'דוא"ל אישור נשלח לכתובת @email@. נא להקליק בקישור שצוין בהודעה כדי לתת תוקף לחתימתך.', # MODIF
	'form_pet_mail_confirmation' => 'שלום,

ביקשת לתחתום את הפטיציה הבאה:
@titre@.

הכנסת את הפרטים הבאים:
    שם: @nom_email@
    אתר: @nom_site@ - @url_site@

לתשומת לבך...
כדי לאשר את חתימתך, צריך שתתחבר/י 
לכתובת הבאה (אם לא, אז בקשתך
תימאס):
    @url@

תודה על השתתפותך
',
	'form_pet_nom_site2' => 'שם האתר שלך', # MODIF
	'form_pet_probleme_liens' => 'נא לתקן את הודעתך בהסרת הקישורים.',
	'form_pet_probleme_technique' => 'בעיה טכנית, חתימות לא עובדות כרגע.',
	'form_pet_signature_validee' => 'החתימה שלך מקובלת. תודה לך !',
	'form_pet_site_deja_enregistre' => 'האתר הזה כבר רשום במערכת',
	'form_pet_url_invalide' => 'הכתובת הכללית שכתבת לא ברת תוקף.',
	'form_pet_votre_email' => 'כתובת הדוא"ל שלך',
	'form_pet_votre_nom' => 'השם או הכינוי שלך', # MODIF
	'form_pet_votre_site' => 'אם ברשותך אתר, כתוב את כתובתו להלן',

	// I
	'info_adresse_email' => ':כתובת דוא"ל',
	'info_signature_supprimee' => 'חתימה נמחקה',
	'info_signature_supprimee_erreur' => 'טעות : קוד המחיקה לא מתאים לאף חתימה', # MODIF
	'info_site_web' => 'אתר אינטרנט :'
);

?>
